CHANGELOG
---------

Development Version
+++++++++++++++++++

0.2.5
*****

* Abstract out =datatypes that perform just Python type checks to reduce code.

0.2.4
*****

* Fix tests for Python 2.5 and 2.6. Fix README.

0.2.3
*****

* Package setup changes - added classifiers and manifest file.

0.2.1
*****

* First public release of Incoming.
